import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.standing_model_fixture_type import StandingModelFixtureType
from ..models.standing_model_grouping_base import StandingModelGroupingBase
from ..models.standing_model_grouping_conference_division import StandingModelGroupingConferenceDivision
from ..models.standing_model_grouping_stage_pool import StandingModelGroupingStagePool
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.standing_model_calculated import StandingModelCalculated
    from ..models.standing_model_conference import StandingModelConference
    from ..models.standing_model_division import StandingModelDivision
    from ..models.standing_model_entity import StandingModelEntity
    from ..models.standing_model_organization import StandingModelOrganization
    from ..models.standing_model_points import StandingModelPoints
    from ..models.standing_model_pool import StandingModelPool
    from ..models.standing_model_round import StandingModelRound
    from ..models.standing_model_season import StandingModelSeason
    from ..models.standing_model_stage import StandingModelStage
    from ..models.standing_model_standing_configuration import StandingModelStandingConfiguration


T = TypeVar("T", bound="StandingModel")


@_attrs_define
class StandingModel:
    """
    Attributes:
        standing_id (Union[Unset, UUID]): The unique identifier of the standing Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, StandingModelOrganization]): The organization that this standing belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, StandingModelSeason]): The season linked to this record
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, StandingModelEntity]): The team information
        division_id (Union[None, UUID, Unset]): The unique identifier of the division Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division (Union[Unset, StandingModelDivision]): The division information
        conference_id (Union[None, UUID, Unset]): The unique identifier of the conference Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        conference (Union[Unset, StandingModelConference]): The conference information
        latest (Union[Unset, bool]): Standing is part of the latest round? Example: True.
        in_progress (Union[Unset, bool]): Is the competitor in a current In-Progress match? Example: True.
        live (Union[Unset, bool]): Is this including live matches? Example: True.
        locked (Union[Unset, bool]): Has the standing been locked (to prevent editing)? Example: True.
        grouping_base (Union[Unset, StandingModelGroupingBase]): Base grouping of standings row
            >- `OVERALL` Overall
            >- `ROUND` Round
             Example: OVERALL.
        grouping_conference_division (Union[Unset, StandingModelGroupingConferenceDivision]): Conference/Division
            grouping of standings row
            >- `CONFERENCE` Conference
            >- `DIVISION` Division
            >- `OVERALL` Overall
             Example: OVERALL.
        grouping_stage_pool (Union[Unset, StandingModelGroupingStagePool]): Stage/Pool grouping of standings row
            >- `OVERALL` Overall
            >- `STAGE` Stage
            >- `STAGEPOOL` Stage/Pool
             Example: OVERALL.
        stage_code (Union[None, Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        stage (Union[Unset, StandingModelStage]): The stage that is related to this record
        pool_code (Union[None, Unset, str]): A unique code for the pool. (Unique for season) Example: P1.
        pool (Union[Unset, StandingModelPool]): The pool that is related to this record
        round_code (Union[None, Unset, str]): A unique code for the round. (Unique for season) Example: RN1.
        round_ (Union[Unset, StandingModelRound]): The ~ROUND~ that is related to this record
        round_number (Union[None, Unset, str]): The number given to the round Example: 1.
        standing_configuration_id (Union[None, UUID, Unset]): The unique identifier of the ~standingConfiguration~
            Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        standing_configuration (Union[Unset, StandingModelStandingConfiguration]): The ~standingConfiguration~ that this
            season belongs to
        fixture_type (Union[Unset, StandingModelFixtureType]): Type of match
            >- `ALL_STAR` All Star
            >- `DEMONSTRATION` Demonstration
            >- `FINAL` Final
            >- `FRIENDLY` Friendly
            >- `PLAYOFF` Playoff
            >- `PRESEASON` Pre Season
            >- `REGULAR` Regular
             Example: REGULAR.
        position (Union[None, Unset, int]): Position of the competitors standing record Example: 48.
        secured_finals (Union[Unset, str]): Has competitor secured a finals position
        points (Union[Unset, StandingModelPoints]): standings points fields
        calculated (Union[Unset, StandingModelCalculated]): standings points fields
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        auto_generated (Union[Unset, bool]): Was this row auto generated? Example: True.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    standing_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "StandingModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "StandingModelSeason"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "StandingModelEntity"] = UNSET
    division_id: Union[None, UUID, Unset] = UNSET
    division: Union[Unset, "StandingModelDivision"] = UNSET
    conference_id: Union[None, UUID, Unset] = UNSET
    conference: Union[Unset, "StandingModelConference"] = UNSET
    latest: Union[Unset, bool] = UNSET
    in_progress: Union[Unset, bool] = UNSET
    live: Union[Unset, bool] = UNSET
    locked: Union[Unset, bool] = UNSET
    grouping_base: Union[Unset, StandingModelGroupingBase] = UNSET
    grouping_conference_division: Union[Unset, StandingModelGroupingConferenceDivision] = UNSET
    grouping_stage_pool: Union[Unset, StandingModelGroupingStagePool] = UNSET
    stage_code: Union[None, Unset, str] = UNSET
    stage: Union[Unset, "StandingModelStage"] = UNSET
    pool_code: Union[None, Unset, str] = UNSET
    pool: Union[Unset, "StandingModelPool"] = UNSET
    round_code: Union[None, Unset, str] = UNSET
    round_: Union[Unset, "StandingModelRound"] = UNSET
    round_number: Union[None, Unset, str] = UNSET
    standing_configuration_id: Union[None, UUID, Unset] = UNSET
    standing_configuration: Union[Unset, "StandingModelStandingConfiguration"] = UNSET
    fixture_type: Union[Unset, StandingModelFixtureType] = UNSET
    position: Union[None, Unset, int] = UNSET
    secured_finals: Union[Unset, str] = UNSET
    points: Union[Unset, "StandingModelPoints"] = UNSET
    calculated: Union[Unset, "StandingModelCalculated"] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    auto_generated: Union[Unset, bool] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        standing_id: Union[Unset, str] = UNSET
        if not isinstance(self.standing_id, Unset):
            standing_id = str(self.standing_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        division_id: Union[None, Unset, str]
        if isinstance(self.division_id, Unset):
            division_id = UNSET
        elif isinstance(self.division_id, UUID):
            division_id = str(self.division_id)
        else:
            division_id = self.division_id

        division: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.division, Unset):
            division = self.division.to_dict()

        conference_id: Union[None, Unset, str]
        if isinstance(self.conference_id, Unset):
            conference_id = UNSET
        elif isinstance(self.conference_id, UUID):
            conference_id = str(self.conference_id)
        else:
            conference_id = self.conference_id

        conference: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.conference, Unset):
            conference = self.conference.to_dict()

        latest = self.latest

        in_progress = self.in_progress

        live = self.live

        locked = self.locked

        grouping_base: Union[Unset, str] = UNSET
        if not isinstance(self.grouping_base, Unset):
            grouping_base = self.grouping_base.value

        grouping_conference_division: Union[Unset, str] = UNSET
        if not isinstance(self.grouping_conference_division, Unset):
            grouping_conference_division = self.grouping_conference_division.value

        grouping_stage_pool: Union[Unset, str] = UNSET
        if not isinstance(self.grouping_stage_pool, Unset):
            grouping_stage_pool = self.grouping_stage_pool.value

        stage_code: Union[None, Unset, str]
        if isinstance(self.stage_code, Unset):
            stage_code = UNSET
        else:
            stage_code = self.stage_code

        stage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stage, Unset):
            stage = self.stage.to_dict()

        pool_code: Union[None, Unset, str]
        if isinstance(self.pool_code, Unset):
            pool_code = UNSET
        else:
            pool_code = self.pool_code

        pool: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pool, Unset):
            pool = self.pool.to_dict()

        round_code: Union[None, Unset, str]
        if isinstance(self.round_code, Unset):
            round_code = UNSET
        else:
            round_code = self.round_code

        round_: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.round_, Unset):
            round_ = self.round_.to_dict()

        round_number: Union[None, Unset, str]
        if isinstance(self.round_number, Unset):
            round_number = UNSET
        else:
            round_number = self.round_number

        standing_configuration_id: Union[None, Unset, str]
        if isinstance(self.standing_configuration_id, Unset):
            standing_configuration_id = UNSET
        elif isinstance(self.standing_configuration_id, UUID):
            standing_configuration_id = str(self.standing_configuration_id)
        else:
            standing_configuration_id = self.standing_configuration_id

        standing_configuration: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.standing_configuration, Unset):
            standing_configuration = self.standing_configuration.to_dict()

        fixture_type: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_type, Unset):
            fixture_type = self.fixture_type.value

        position: Union[None, Unset, int]
        if isinstance(self.position, Unset):
            position = UNSET
        else:
            position = self.position

        secured_finals = self.secured_finals

        points: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.points, Unset):
            points = self.points.to_dict()

        calculated: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.calculated, Unset):
            calculated = self.calculated.to_dict()

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        auto_generated = self.auto_generated

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if standing_id is not UNSET:
            field_dict["standingId"] = standing_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if division is not UNSET:
            field_dict["division"] = division
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if conference is not UNSET:
            field_dict["conference"] = conference
        if latest is not UNSET:
            field_dict["latest"] = latest
        if in_progress is not UNSET:
            field_dict["inProgress"] = in_progress
        if live is not UNSET:
            field_dict["live"] = live
        if locked is not UNSET:
            field_dict["locked"] = locked
        if grouping_base is not UNSET:
            field_dict["groupingBase"] = grouping_base
        if grouping_conference_division is not UNSET:
            field_dict["groupingConferenceDivision"] = grouping_conference_division
        if grouping_stage_pool is not UNSET:
            field_dict["groupingStagePool"] = grouping_stage_pool
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if stage is not UNSET:
            field_dict["stage"] = stage
        if pool_code is not UNSET:
            field_dict["poolCode"] = pool_code
        if pool is not UNSET:
            field_dict["pool"] = pool
        if round_code is not UNSET:
            field_dict["roundCode"] = round_code
        if round_ is not UNSET:
            field_dict["round"] = round_
        if round_number is not UNSET:
            field_dict["roundNumber"] = round_number
        if standing_configuration_id is not UNSET:
            field_dict["standingConfigurationId"] = standing_configuration_id
        if standing_configuration is not UNSET:
            field_dict["standingConfiguration"] = standing_configuration
        if fixture_type is not UNSET:
            field_dict["fixtureType"] = fixture_type
        if position is not UNSET:
            field_dict["position"] = position
        if secured_finals is not UNSET:
            field_dict["securedFinals"] = secured_finals
        if points is not UNSET:
            field_dict["points"] = points
        if calculated is not UNSET:
            field_dict["calculated"] = calculated
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if auto_generated is not UNSET:
            field_dict["autoGenerated"] = auto_generated
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.standing_model_calculated import StandingModelCalculated
        from ..models.standing_model_conference import StandingModelConference
        from ..models.standing_model_division import StandingModelDivision
        from ..models.standing_model_entity import StandingModelEntity
        from ..models.standing_model_organization import StandingModelOrganization
        from ..models.standing_model_points import StandingModelPoints
        from ..models.standing_model_pool import StandingModelPool
        from ..models.standing_model_round import StandingModelRound
        from ..models.standing_model_season import StandingModelSeason
        from ..models.standing_model_stage import StandingModelStage
        from ..models.standing_model_standing_configuration import StandingModelStandingConfiguration

        d = dict(src_dict)
        _standing_id = d.pop("standingId", UNSET)
        standing_id: Union[Unset, UUID]
        if isinstance(_standing_id, Unset):
            standing_id = UNSET
        else:
            standing_id = UUID(_standing_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, StandingModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = StandingModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, StandingModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = StandingModelSeason.from_dict(_season)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, StandingModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = StandingModelEntity.from_dict(_entity)

        def _parse_division_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                division_id_type_0 = UUID(data)

                return division_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        division_id = _parse_division_id(d.pop("divisionId", UNSET))

        _division = d.pop("division", UNSET)
        division: Union[Unset, StandingModelDivision]
        if isinstance(_division, Unset):
            division = UNSET
        else:
            division = StandingModelDivision.from_dict(_division)

        def _parse_conference_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                conference_id_type_0 = UUID(data)

                return conference_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        conference_id = _parse_conference_id(d.pop("conferenceId", UNSET))

        _conference = d.pop("conference", UNSET)
        conference: Union[Unset, StandingModelConference]
        if isinstance(_conference, Unset):
            conference = UNSET
        else:
            conference = StandingModelConference.from_dict(_conference)

        latest = d.pop("latest", UNSET)

        in_progress = d.pop("inProgress", UNSET)

        live = d.pop("live", UNSET)

        locked = d.pop("locked", UNSET)

        _grouping_base = d.pop("groupingBase", UNSET)
        grouping_base: Union[Unset, StandingModelGroupingBase]
        if isinstance(_grouping_base, Unset):
            grouping_base = UNSET
        else:
            grouping_base = StandingModelGroupingBase(_grouping_base)

        _grouping_conference_division = d.pop("groupingConferenceDivision", UNSET)
        grouping_conference_division: Union[Unset, StandingModelGroupingConferenceDivision]
        if isinstance(_grouping_conference_division, Unset):
            grouping_conference_division = UNSET
        else:
            grouping_conference_division = StandingModelGroupingConferenceDivision(_grouping_conference_division)

        _grouping_stage_pool = d.pop("groupingStagePool", UNSET)
        grouping_stage_pool: Union[Unset, StandingModelGroupingStagePool]
        if isinstance(_grouping_stage_pool, Unset):
            grouping_stage_pool = UNSET
        else:
            grouping_stage_pool = StandingModelGroupingStagePool(_grouping_stage_pool)

        def _parse_stage_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage_code = _parse_stage_code(d.pop("stageCode", UNSET))

        _stage = d.pop("stage", UNSET)
        stage: Union[Unset, StandingModelStage]
        if isinstance(_stage, Unset):
            stage = UNSET
        else:
            stage = StandingModelStage.from_dict(_stage)

        def _parse_pool_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        pool_code = _parse_pool_code(d.pop("poolCode", UNSET))

        _pool = d.pop("pool", UNSET)
        pool: Union[Unset, StandingModelPool]
        if isinstance(_pool, Unset):
            pool = UNSET
        else:
            pool = StandingModelPool.from_dict(_pool)

        def _parse_round_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_code = _parse_round_code(d.pop("roundCode", UNSET))

        _round_ = d.pop("round", UNSET)
        round_: Union[Unset, StandingModelRound]
        if isinstance(_round_, Unset):
            round_ = UNSET
        else:
            round_ = StandingModelRound.from_dict(_round_)

        def _parse_round_number(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_number = _parse_round_number(d.pop("roundNumber", UNSET))

        def _parse_standing_configuration_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                standing_configuration_id_type_0 = UUID(data)

                return standing_configuration_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        standing_configuration_id = _parse_standing_configuration_id(d.pop("standingConfigurationId", UNSET))

        _standing_configuration = d.pop("standingConfiguration", UNSET)
        standing_configuration: Union[Unset, StandingModelStandingConfiguration]
        if isinstance(_standing_configuration, Unset):
            standing_configuration = UNSET
        else:
            standing_configuration = StandingModelStandingConfiguration.from_dict(_standing_configuration)

        _fixture_type = d.pop("fixtureType", UNSET)
        fixture_type: Union[Unset, StandingModelFixtureType]
        if isinstance(_fixture_type, Unset):
            fixture_type = UNSET
        else:
            fixture_type = StandingModelFixtureType(_fixture_type)

        def _parse_position(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        position = _parse_position(d.pop("position", UNSET))

        secured_finals = d.pop("securedFinals", UNSET)

        _points = d.pop("points", UNSET)
        points: Union[Unset, StandingModelPoints]
        if isinstance(_points, Unset):
            points = UNSET
        else:
            points = StandingModelPoints.from_dict(_points)

        _calculated = d.pop("calculated", UNSET)
        calculated: Union[Unset, StandingModelCalculated]
        if isinstance(_calculated, Unset):
            calculated = UNSET
        else:
            calculated = StandingModelCalculated.from_dict(_calculated)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        auto_generated = d.pop("autoGenerated", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        standing_model = cls(
            standing_id=standing_id,
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            entity_id=entity_id,
            entity=entity,
            division_id=division_id,
            division=division,
            conference_id=conference_id,
            conference=conference,
            latest=latest,
            in_progress=in_progress,
            live=live,
            locked=locked,
            grouping_base=grouping_base,
            grouping_conference_division=grouping_conference_division,
            grouping_stage_pool=grouping_stage_pool,
            stage_code=stage_code,
            stage=stage,
            pool_code=pool_code,
            pool=pool,
            round_code=round_code,
            round_=round_,
            round_number=round_number,
            standing_configuration_id=standing_configuration_id,
            standing_configuration=standing_configuration,
            fixture_type=fixture_type,
            position=position,
            secured_finals=secured_finals,
            points=points,
            calculated=calculated,
            external_id=external_id,
            auto_generated=auto_generated,
            updated=updated,
            added=added,
        )

        return standing_model



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_person_statistics_model_competition import SeasonPersonStatisticsModelCompetition
    from ..models.season_person_statistics_model_entity import SeasonPersonStatisticsModelEntity
    from ..models.season_person_statistics_model_organization import SeasonPersonStatisticsModelOrganization
    from ..models.season_person_statistics_model_person import SeasonPersonStatisticsModelPerson
    from ..models.season_person_statistics_model_season import SeasonPersonStatisticsModelSeason
    from ..models.season_person_statistics_model_statistics import SeasonPersonStatisticsModelStatistics


T = TypeVar("T", bound="SeasonPersonStatisticsModel")


@_attrs_define
class SeasonPersonStatisticsModel:
    """
    Attributes:
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, SeasonPersonStatisticsModelPerson]): The person information
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, SeasonPersonStatisticsModelEntity]): The team information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonPersonStatisticsModelOrganization]): The organization that this season person
            statistics belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonPersonStatisticsModelSeason]): The season linked to this record
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, SeasonPersonStatisticsModelCompetition]): The competition that this season belongs to
        statistics (Union[Unset, SeasonPersonStatisticsModelStatistics]):
    """

    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "SeasonPersonStatisticsModelPerson"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "SeasonPersonStatisticsModelEntity"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonPersonStatisticsModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonPersonStatisticsModelSeason"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "SeasonPersonStatisticsModelCompetition"] = UNSET
    statistics: Union[Unset, "SeasonPersonStatisticsModelStatistics"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if statistics is not UNSET:
            field_dict["statistics"] = statistics

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_person_statistics_model_competition import SeasonPersonStatisticsModelCompetition
        from ..models.season_person_statistics_model_entity import SeasonPersonStatisticsModelEntity
        from ..models.season_person_statistics_model_organization import SeasonPersonStatisticsModelOrganization
        from ..models.season_person_statistics_model_person import SeasonPersonStatisticsModelPerson
        from ..models.season_person_statistics_model_season import SeasonPersonStatisticsModelSeason
        from ..models.season_person_statistics_model_statistics import SeasonPersonStatisticsModelStatistics

        d = dict(src_dict)
        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, SeasonPersonStatisticsModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = SeasonPersonStatisticsModelPerson.from_dict(_person)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, SeasonPersonStatisticsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = SeasonPersonStatisticsModelEntity.from_dict(_entity)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonPersonStatisticsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonPersonStatisticsModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonPersonStatisticsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonPersonStatisticsModelSeason.from_dict(_season)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, SeasonPersonStatisticsModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = SeasonPersonStatisticsModelCompetition.from_dict(_competition)

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, SeasonPersonStatisticsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = SeasonPersonStatisticsModelStatistics.from_dict(_statistics)

        season_person_statistics_model = cls(
            person_id=person_id,
            person=person,
            entity_id=entity_id,
            entity=entity,
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            competition_id=competition_id,
            competition=competition,
            statistics=statistics,
        )

        return season_person_statistics_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.season_roster_model_position_type_1 import SeasonRosterModelPositionType1
from ..models.season_roster_model_position_type_2_type_1 import SeasonRosterModelPositionType2Type1
from ..models.season_roster_model_position_type_3_type_1 import SeasonRosterModelPositionType3Type1
from ..models.season_roster_model_status import SeasonRosterModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_roster_model_conference import SeasonRosterModelConference
    from ..models.season_roster_model_division import SeasonRosterModelDivision
    from ..models.season_roster_model_entity import SeasonRosterModelEntity
    from ..models.season_roster_model_entity_group import SeasonRosterModelEntityGroup
    from ..models.season_roster_model_organization import SeasonRosterModelOrganization
    from ..models.season_roster_model_person import SeasonRosterModelPerson
    from ..models.season_roster_model_season import SeasonRosterModelSeason


T = TypeVar("T", bound="SeasonRosterModel")


@_attrs_define
class SeasonRosterModel:
    """
    Attributes:
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonRosterModelSeason]): The season linked to this record
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonRosterModelOrganization]): The organization that this season roster belongs to
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, SeasonRosterModelEntity]): The team information
        entity_group_id (Union[None, UUID, Unset]): The club that this team belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, SeasonRosterModelEntityGroup]): The club that this team belongs to
        division_id (Union[None, UUID, Unset]): The unique identifier of the division Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division (Union[Unset, SeasonRosterModelDivision]): The division information
        conference_id (Union[None, UUID, Unset]): The unique identifier of the conference Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        conference (Union[Unset, SeasonRosterModelConference]): The conference information
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, SeasonRosterModelPerson]): The person information
        bib (Union[None, Unset, str]): The number displayed on the jersey Example: 34.
        position (Union[None, SeasonRosterModelPositionType1, SeasonRosterModelPositionType2Type1,
            SeasonRosterModelPositionType3Type1, Unset]): Playing position
            >- None None
            >- `CB` Center Backcourt
            >- `D` Defensive Specialist
            >- `G` Goalkeeper
            >- `LB` Left Backcourt
            >- `LW` Left Wingman
            >- `P` Pivot
            >- `RB` Right Backcourt
            >- `RW` Right Wingman
             Example: G.
        status (Union[Unset, SeasonRosterModelStatus]): Participation status
            >- `ACTIVE` Active
            >- `INJURED` Injured
            >- `OTHER_NOT_PARTICIPATING` Other Non-Participation
            >- `OUT` Out
            >- `SUSPENDED` Suspended
             Example: ACTIVE.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonRosterModelSeason"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonRosterModelOrganization"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "SeasonRosterModelEntity"] = UNSET
    entity_group_id: Union[None, UUID, Unset] = UNSET
    entity_group: Union[Unset, "SeasonRosterModelEntityGroup"] = UNSET
    division_id: Union[None, UUID, Unset] = UNSET
    division: Union[Unset, "SeasonRosterModelDivision"] = UNSET
    conference_id: Union[None, UUID, Unset] = UNSET
    conference: Union[Unset, "SeasonRosterModelConference"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "SeasonRosterModelPerson"] = UNSET
    bib: Union[None, Unset, str] = UNSET
    position: Union[
        None,
        SeasonRosterModelPositionType1,
        SeasonRosterModelPositionType2Type1,
        SeasonRosterModelPositionType3Type1,
        Unset,
    ] = UNSET
    status: Union[Unset, SeasonRosterModelStatus] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        entity_group_id: Union[None, Unset, str]
        if isinstance(self.entity_group_id, Unset):
            entity_group_id = UNSET
        elif isinstance(self.entity_group_id, UUID):
            entity_group_id = str(self.entity_group_id)
        else:
            entity_group_id = self.entity_group_id

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        division_id: Union[None, Unset, str]
        if isinstance(self.division_id, Unset):
            division_id = UNSET
        elif isinstance(self.division_id, UUID):
            division_id = str(self.division_id)
        else:
            division_id = self.division_id

        division: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.division, Unset):
            division = self.division.to_dict()

        conference_id: Union[None, Unset, str]
        if isinstance(self.conference_id, Unset):
            conference_id = UNSET
        elif isinstance(self.conference_id, UUID):
            conference_id = str(self.conference_id)
        else:
            conference_id = self.conference_id

        conference: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.conference, Unset):
            conference = self.conference.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        bib: Union[None, Unset, str]
        if isinstance(self.bib, Unset):
            bib = UNSET
        else:
            bib = self.bib

        position: Union[None, Unset, str]
        if isinstance(self.position, Unset):
            position = UNSET
        elif isinstance(self.position, SeasonRosterModelPositionType1):
            position = self.position.value
        elif isinstance(self.position, SeasonRosterModelPositionType2Type1):
            position = self.position.value
        elif isinstance(self.position, SeasonRosterModelPositionType3Type1):
            position = self.position.value
        else:
            position = self.position

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if division is not UNSET:
            field_dict["division"] = division
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if conference is not UNSET:
            field_dict["conference"] = conference
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if bib is not UNSET:
            field_dict["bib"] = bib
        if position is not UNSET:
            field_dict["position"] = position
        if status is not UNSET:
            field_dict["status"] = status
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_roster_model_conference import SeasonRosterModelConference
        from ..models.season_roster_model_division import SeasonRosterModelDivision
        from ..models.season_roster_model_entity import SeasonRosterModelEntity
        from ..models.season_roster_model_entity_group import SeasonRosterModelEntityGroup
        from ..models.season_roster_model_organization import SeasonRosterModelOrganization
        from ..models.season_roster_model_person import SeasonRosterModelPerson
        from ..models.season_roster_model_season import SeasonRosterModelSeason

        d = dict(src_dict)
        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonRosterModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonRosterModelSeason.from_dict(_season)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonRosterModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonRosterModelOrganization.from_dict(_organization)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, SeasonRosterModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = SeasonRosterModelEntity.from_dict(_entity)

        def _parse_entity_group_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                entity_group_id_type_0 = UUID(data)

                return entity_group_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        entity_group_id = _parse_entity_group_id(d.pop("entityGroupId", UNSET))

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, SeasonRosterModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = SeasonRosterModelEntityGroup.from_dict(_entity_group)

        def _parse_division_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                division_id_type_0 = UUID(data)

                return division_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        division_id = _parse_division_id(d.pop("divisionId", UNSET))

        _division = d.pop("division", UNSET)
        division: Union[Unset, SeasonRosterModelDivision]
        if isinstance(_division, Unset):
            division = UNSET
        else:
            division = SeasonRosterModelDivision.from_dict(_division)

        def _parse_conference_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                conference_id_type_0 = UUID(data)

                return conference_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        conference_id = _parse_conference_id(d.pop("conferenceId", UNSET))

        _conference = d.pop("conference", UNSET)
        conference: Union[Unset, SeasonRosterModelConference]
        if isinstance(_conference, Unset):
            conference = UNSET
        else:
            conference = SeasonRosterModelConference.from_dict(_conference)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, SeasonRosterModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = SeasonRosterModelPerson.from_dict(_person)

        def _parse_bib(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        bib = _parse_bib(d.pop("bib", UNSET))

        def _parse_position(
            data: object,
        ) -> Union[
            None,
            SeasonRosterModelPositionType1,
            SeasonRosterModelPositionType2Type1,
            SeasonRosterModelPositionType3Type1,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_1 = SeasonRosterModelPositionType1(data)

                return position_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_2_type_1 = SeasonRosterModelPositionType2Type1(data)

                return position_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_3_type_1 = SeasonRosterModelPositionType3Type1(data)

                return position_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    None,
                    SeasonRosterModelPositionType1,
                    SeasonRosterModelPositionType2Type1,
                    SeasonRosterModelPositionType3Type1,
                    Unset,
                ],
                data,
            )

        position = _parse_position(d.pop("position", UNSET))

        _status = d.pop("status", UNSET)
        status: Union[Unset, SeasonRosterModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = SeasonRosterModelStatus(_status)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        season_roster_model = cls(
            season_id=season_id,
            season=season,
            organization_id=organization_id,
            organization=organization,
            entity_id=entity_id,
            entity=entity,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            division_id=division_id,
            division=division,
            conference_id=conference_id,
            conference=conference,
            person_id=person_id,
            person=person,
            bib=bib,
            position=position,
            status=status,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return season_roster_model



from enum import Enum


class ImagesListIdRating(str, Enum):
    HIGH = "HIGH"
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    UNKNOWN = "UNKNOWN"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.transfer_model_status_type_1 import TransferModelStatusType1
from ..models.transfer_model_status_type_2_type_1 import TransferModelStatusType2Type1
from ..models.transfer_model_status_type_3_type_1 import TransferModelStatusType3Type1
from ..models.transfer_model_transfer_type import TransferModelTransferType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.transfer_model_competition import TransferModelCompetition
    from ..models.transfer_model_organization import TransferModelOrganization
    from ..models.transfer_model_season import TransferModelSeason
    from ..models.transfer_model_transfer_component import TransferModelTransferComponent


T = TypeVar("T", bound="TransferModel")


@_attrs_define
class TransferModel:
    """
    Attributes:
        transfer_id (Union[Unset, UUID]): The unique identifier of the transfer Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, TransferModelOrganization]): The organization that this ~transfer~ belongs to
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, TransferModelCompetition]): The competition that this season belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, TransferModelSeason]): The season linked to this record
        components (Union[None, Unset, list['TransferModelTransferComponent']]): List of transfer components
        status (Union[None, TransferModelStatusType1, TransferModelStatusType2Type1, TransferModelStatusType3Type1,
            Unset]): Transfer Status
            >- None None
            >- `APPROVED` Approved
            >- `DECLINED` Decline
            >- `PENDING` Pending
             Example: APPROVED.
        reference (Union[Unset, str]): Transfer reference number
        transfer_type (Union[Unset, TransferModelTransferType]): Type of transfer
            >- `DROPPED` Dropped
            >- `OTHER` Other
            >- `PERMIT` Permit
            >- `TRADE` Trade
            >- `TRANSFER` Transfer
             Example: TRANSFER.
        date_transfer (Union[None, Unset, datetime.date]): Date of transfer Example: 1978-08-24.
        date_permit_from (Union[None, Unset, datetime.date]): Date the permit started Example: 1978-08-24.
        date_permit_to (Union[None, Unset, datetime.date]): Date the permit ended Example: 1978-08-24.
        notes (Union[None, Unset, str]): Notes
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    transfer_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "TransferModelOrganization"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "TransferModelCompetition"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "TransferModelSeason"] = UNSET
    components: Union[None, Unset, list["TransferModelTransferComponent"]] = UNSET
    status: Union[
        None, TransferModelStatusType1, TransferModelStatusType2Type1, TransferModelStatusType3Type1, Unset
    ] = UNSET
    reference: Union[Unset, str] = UNSET
    transfer_type: Union[Unset, TransferModelTransferType] = UNSET
    date_transfer: Union[None, Unset, datetime.date] = UNSET
    date_permit_from: Union[None, Unset, datetime.date] = UNSET
    date_permit_to: Union[None, Unset, datetime.date] = UNSET
    notes: Union[None, Unset, str] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        transfer_id: Union[Unset, str] = UNSET
        if not isinstance(self.transfer_id, Unset):
            transfer_id = str(self.transfer_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        components: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.components, Unset):
            components = UNSET
        elif isinstance(self.components, list):
            components = []
            for components_type_0_item_data in self.components:
                components_type_0_item = components_type_0_item_data.to_dict()
                components.append(components_type_0_item)

        else:
            components = self.components

        status: Union[None, Unset, str]
        if isinstance(self.status, Unset):
            status = UNSET
        elif isinstance(self.status, TransferModelStatusType1):
            status = self.status.value
        elif isinstance(self.status, TransferModelStatusType2Type1):
            status = self.status.value
        elif isinstance(self.status, TransferModelStatusType3Type1):
            status = self.status.value
        else:
            status = self.status

        reference = self.reference

        transfer_type: Union[Unset, str] = UNSET
        if not isinstance(self.transfer_type, Unset):
            transfer_type = self.transfer_type.value

        date_transfer: Union[None, Unset, str]
        if isinstance(self.date_transfer, Unset):
            date_transfer = UNSET
        elif isinstance(self.date_transfer, datetime.date):
            date_transfer = self.date_transfer.isoformat()
        else:
            date_transfer = self.date_transfer

        date_permit_from: Union[None, Unset, str]
        if isinstance(self.date_permit_from, Unset):
            date_permit_from = UNSET
        elif isinstance(self.date_permit_from, datetime.date):
            date_permit_from = self.date_permit_from.isoformat()
        else:
            date_permit_from = self.date_permit_from

        date_permit_to: Union[None, Unset, str]
        if isinstance(self.date_permit_to, Unset):
            date_permit_to = UNSET
        elif isinstance(self.date_permit_to, datetime.date):
            date_permit_to = self.date_permit_to.isoformat()
        else:
            date_permit_to = self.date_permit_to

        notes: Union[None, Unset, str]
        if isinstance(self.notes, Unset):
            notes = UNSET
        else:
            notes = self.notes

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if transfer_id is not UNSET:
            field_dict["transferId"] = transfer_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if components is not UNSET:
            field_dict["components"] = components
        if status is not UNSET:
            field_dict["status"] = status
        if reference is not UNSET:
            field_dict["reference"] = reference
        if transfer_type is not UNSET:
            field_dict["transferType"] = transfer_type
        if date_transfer is not UNSET:
            field_dict["dateTransfer"] = date_transfer
        if date_permit_from is not UNSET:
            field_dict["datePermitFrom"] = date_permit_from
        if date_permit_to is not UNSET:
            field_dict["datePermitTo"] = date_permit_to
        if notes is not UNSET:
            field_dict["notes"] = notes
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.transfer_model_competition import TransferModelCompetition
        from ..models.transfer_model_organization import TransferModelOrganization
        from ..models.transfer_model_season import TransferModelSeason
        from ..models.transfer_model_transfer_component import TransferModelTransferComponent

        d = dict(src_dict)
        _transfer_id = d.pop("transferId", UNSET)
        transfer_id: Union[Unset, UUID]
        if isinstance(_transfer_id, Unset):
            transfer_id = UNSET
        else:
            transfer_id = UUID(_transfer_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, TransferModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = TransferModelOrganization.from_dict(_organization)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, TransferModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = TransferModelCompetition.from_dict(_competition)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, TransferModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = TransferModelSeason.from_dict(_season)

        def _parse_components(data: object) -> Union[None, Unset, list["TransferModelTransferComponent"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                components_type_0 = []
                _components_type_0 = data
                for components_type_0_item_data in _components_type_0:
                    components_type_0_item = TransferModelTransferComponent.from_dict(components_type_0_item_data)

                    components_type_0.append(components_type_0_item)

                return components_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["TransferModelTransferComponent"]], data)

        components = _parse_components(d.pop("components", UNSET))

        def _parse_status(
            data: object,
        ) -> Union[None, TransferModelStatusType1, TransferModelStatusType2Type1, TransferModelStatusType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_1 = TransferModelStatusType1(data)

                return status_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_2_type_1 = TransferModelStatusType2Type1(data)

                return status_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_3_type_1 = TransferModelStatusType3Type1(data)

                return status_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    None, TransferModelStatusType1, TransferModelStatusType2Type1, TransferModelStatusType3Type1, Unset
                ],
                data,
            )

        status = _parse_status(d.pop("status", UNSET))

        reference = d.pop("reference", UNSET)

        _transfer_type = d.pop("transferType", UNSET)
        transfer_type: Union[Unset, TransferModelTransferType]
        if isinstance(_transfer_type, Unset):
            transfer_type = UNSET
        else:
            transfer_type = TransferModelTransferType(_transfer_type)

        def _parse_date_transfer(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_transfer_type_0 = isoparse(data).date()

                return date_transfer_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_transfer = _parse_date_transfer(d.pop("dateTransfer", UNSET))

        def _parse_date_permit_from(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_permit_from_type_0 = isoparse(data).date()

                return date_permit_from_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_permit_from = _parse_date_permit_from(d.pop("datePermitFrom", UNSET))

        def _parse_date_permit_to(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_permit_to_type_0 = isoparse(data).date()

                return date_permit_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_permit_to = _parse_date_permit_to(d.pop("datePermitTo", UNSET))

        def _parse_notes(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        notes = _parse_notes(d.pop("notes", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        transfer_model = cls(
            transfer_id=transfer_id,
            organization_id=organization_id,
            organization=organization,
            competition_id=competition_id,
            competition=competition,
            season_id=season_id,
            season=season,
            components=components,
            status=status,
            reference=reference,
            transfer_type=transfer_type,
            date_transfer=date_transfer,
            date_permit_from=date_permit_from,
            date_permit_to=date_permit_to,
            notes=notes,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return transfer_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.standing_configurations_model_organization import StandingConfigurationsModelOrganization
    from ..models.standing_configurations_model_standing_building import StandingConfigurationsModelStandingBuilding
    from ..models.standing_configurations_model_standing_configuration import (
        StandingConfigurationsModelStandingConfiguration,
    )


T = TypeVar("T", bound="StandingConfigurationsModel")


@_attrs_define
class StandingConfigurationsModel:
    """
    Attributes:
        standing_configuration_id (Union[Unset, UUID]): The unique identifier of the configuration Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, StandingConfigurationsModelOrganization]): The organization that this
            ~standing_configurations~ belongs to
        name_local (Union[Unset, str]): The name of the ~standing_configurations~ in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: Test season.
        name_latin (Union[None, Unset, str]): The name of the ~standing_configurations~ in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: Test season.
        build_rules (Union[Unset, StandingConfigurationsModelStandingBuilding]): Suilding definitions
        configuration (Union[Unset, StandingConfigurationsModelStandingConfiguration]): Configuration definitions
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    standing_configuration_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "StandingConfigurationsModelOrganization"] = UNSET
    name_local: Union[Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    build_rules: Union[Unset, "StandingConfigurationsModelStandingBuilding"] = UNSET
    configuration: Union[Unset, "StandingConfigurationsModelStandingConfiguration"] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        standing_configuration_id: Union[Unset, str] = UNSET
        if not isinstance(self.standing_configuration_id, Unset):
            standing_configuration_id = str(self.standing_configuration_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        name_local = self.name_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        build_rules: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.build_rules, Unset):
            build_rules = self.build_rules.to_dict()

        configuration: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.configuration, Unset):
            configuration = self.configuration.to_dict()

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if standing_configuration_id is not UNSET:
            field_dict["standingConfigurationId"] = standing_configuration_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if build_rules is not UNSET:
            field_dict["buildRules"] = build_rules
        if configuration is not UNSET:
            field_dict["configuration"] = configuration
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.standing_configurations_model_organization import StandingConfigurationsModelOrganization
        from ..models.standing_configurations_model_standing_building import StandingConfigurationsModelStandingBuilding
        from ..models.standing_configurations_model_standing_configuration import (
            StandingConfigurationsModelStandingConfiguration,
        )

        d = dict(src_dict)
        _standing_configuration_id = d.pop("standingConfigurationId", UNSET)
        standing_configuration_id: Union[Unset, UUID]
        if isinstance(_standing_configuration_id, Unset):
            standing_configuration_id = UNSET
        else:
            standing_configuration_id = UUID(_standing_configuration_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, StandingConfigurationsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = StandingConfigurationsModelOrganization.from_dict(_organization)

        name_local = d.pop("nameLocal", UNSET)

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        _build_rules = d.pop("buildRules", UNSET)
        build_rules: Union[Unset, StandingConfigurationsModelStandingBuilding]
        if isinstance(_build_rules, Unset):
            build_rules = UNSET
        else:
            build_rules = StandingConfigurationsModelStandingBuilding.from_dict(_build_rules)

        _configuration = d.pop("configuration", UNSET)
        configuration: Union[Unset, StandingConfigurationsModelStandingConfiguration]
        if isinstance(_configuration, Unset):
            configuration = UNSET
        else:
            configuration = StandingConfigurationsModelStandingConfiguration.from_dict(_configuration)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        standing_configurations_model = cls(
            standing_configuration_id=standing_configuration_id,
            organization_id=organization_id,
            organization=organization,
            name_local=name_local,
            name_latin=name_latin,
            build_rules=build_rules,
            configuration=configuration,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return standing_configurations_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.season_team_base_statistics_model_competitor_type import SeasonTeamBaseStatisticsModelCompetitorType
from ..models.season_team_base_statistics_model_fixture_type import SeasonTeamBaseStatisticsModelFixtureType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_team_base_statistics_model_entity import SeasonTeamBaseStatisticsModelEntity
    from ..models.season_team_base_statistics_model_organization import SeasonTeamBaseStatisticsModelOrganization
    from ..models.season_team_base_statistics_model_season import SeasonTeamBaseStatisticsModelSeason
    from ..models.season_team_base_statistics_model_statistics import SeasonTeamBaseStatisticsModelStatistics


T = TypeVar("T", bound="SeasonTeamBaseStatisticsModel")


@_attrs_define
class SeasonTeamBaseStatisticsModel:
    """
    Attributes:
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonTeamBaseStatisticsModelSeason]): The season linked to this record
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, SeasonTeamBaseStatisticsModelEntity]): The team information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonTeamBaseStatisticsModelOrganization]): The organization that this season team
            base statistics belongs to
        fixture_type (Union[Unset, SeasonTeamBaseStatisticsModelFixtureType]): Type of match
            >- `ALL_STAR` All Star
            >- `DEMONSTRATION` Demonstration
            >- `FINAL` Final
            >- `FRIENDLY` Friendly
            >- `PLAYOFF` Playoff
            >- `PRESEASON` Pre Season
            >- `REGULAR` Regular
             Example: REGULAR.
        competitor_type (Union[Unset, SeasonTeamBaseStatisticsModelCompetitorType]): The type of competitors in this
            match
            >- `ENTITY` Entity
            >- `PERSON` Person
             Example: ENTITY.
        representing (Union[Unset, str]): Who was being represented for the season base statistics Example: AUSTRALIA.
        statistics (Union[Unset, SeasonTeamBaseStatisticsModelStatistics]):
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonTeamBaseStatisticsModelSeason"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "SeasonTeamBaseStatisticsModelEntity"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonTeamBaseStatisticsModelOrganization"] = UNSET
    fixture_type: Union[Unset, SeasonTeamBaseStatisticsModelFixtureType] = UNSET
    competitor_type: Union[Unset, SeasonTeamBaseStatisticsModelCompetitorType] = UNSET
    representing: Union[Unset, str] = UNSET
    statistics: Union[Unset, "SeasonTeamBaseStatisticsModelStatistics"] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        fixture_type: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_type, Unset):
            fixture_type = self.fixture_type.value

        competitor_type: Union[Unset, str] = UNSET
        if not isinstance(self.competitor_type, Unset):
            competitor_type = self.competitor_type.value

        representing = self.representing

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if fixture_type is not UNSET:
            field_dict["fixtureType"] = fixture_type
        if competitor_type is not UNSET:
            field_dict["competitorType"] = competitor_type
        if representing is not UNSET:
            field_dict["representing"] = representing
        if statistics is not UNSET:
            field_dict["statistics"] = statistics
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_team_base_statistics_model_entity import SeasonTeamBaseStatisticsModelEntity
        from ..models.season_team_base_statistics_model_organization import SeasonTeamBaseStatisticsModelOrganization
        from ..models.season_team_base_statistics_model_season import SeasonTeamBaseStatisticsModelSeason
        from ..models.season_team_base_statistics_model_statistics import SeasonTeamBaseStatisticsModelStatistics

        d = dict(src_dict)
        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonTeamBaseStatisticsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonTeamBaseStatisticsModelSeason.from_dict(_season)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, SeasonTeamBaseStatisticsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = SeasonTeamBaseStatisticsModelEntity.from_dict(_entity)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonTeamBaseStatisticsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonTeamBaseStatisticsModelOrganization.from_dict(_organization)

        _fixture_type = d.pop("fixtureType", UNSET)
        fixture_type: Union[Unset, SeasonTeamBaseStatisticsModelFixtureType]
        if isinstance(_fixture_type, Unset):
            fixture_type = UNSET
        else:
            fixture_type = SeasonTeamBaseStatisticsModelFixtureType(_fixture_type)

        _competitor_type = d.pop("competitorType", UNSET)
        competitor_type: Union[Unset, SeasonTeamBaseStatisticsModelCompetitorType]
        if isinstance(_competitor_type, Unset):
            competitor_type = UNSET
        else:
            competitor_type = SeasonTeamBaseStatisticsModelCompetitorType(_competitor_type)

        representing = d.pop("representing", UNSET)

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, SeasonTeamBaseStatisticsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = SeasonTeamBaseStatisticsModelStatistics.from_dict(_statistics)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        season_team_base_statistics_model = cls(
            season_id=season_id,
            season=season,
            entity_id=entity_id,
            entity=entity,
            organization_id=organization_id,
            organization=organization,
            fixture_type=fixture_type,
            competitor_type=competitor_type,
            representing=representing,
            statistics=statistics,
            updated=updated,
            added=added,
        )

        return season_team_base_statistics_model



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="PartnersGetBlankModelGetBody")


@_attrs_define
class PartnersGetBlankModelGetBody:
    """ """

    def to_dict(self) -> dict[str, Any]:
        field_dict: dict[str, Any] = {}

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        partners_get_blank_model_get_body = cls()

        return partners_get_blank_model_get_body



from enum import IntEnum


class FesListperiodPeriodId(IntEnum):
    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_10 = 10
    VALUE_11 = 11
    VALUE_12 = 12
    VALUE_13 = 13
    VALUE_14 = 14

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class EntityListByEntityGroupStandard(str, Enum):
    ELITE = "ELITE"
    FRIENDLY = "FRIENDLY"
    GRASS_ROOT = "GRASS_ROOT"
    HOCKEY_SERIES_OPEN = "HOCKEY_SERIES_OPEN"
    INTERNATIONAL = "INTERNATIONAL"
    NONCONTINENTAL_CHAMPIONSHIP = "NONCONTINENTAL_CHAMPIONSHIP"
    OLYMPIC = "OLYMPIC"
    REGION = "REGION"
    TIER2 = "TIER2"
    TIER3 = "TIER3"
    WORLD_CHAMPIONSHIP = "WORLD_CHAMPIONSHIP"
    WORLD_LEAGUE = "WORLD_LEAGUE"
    ZONE_CHAMPIONSHIP = "ZONE_CHAMPIONSHIP"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.video_subscription_model_audio import VideoSubscriptionModelAudio
from ..models.video_subscription_model_content import VideoSubscriptionModelContent
from ..models.video_subscription_model_feed_type import VideoSubscriptionModelFeedType
from ..models.video_subscription_model_output_format import VideoSubscriptionModelOutputFormat
from ..models.video_subscription_model_output_resolution import VideoSubscriptionModelOutputResolution
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.video_subscription_model_fixture import VideoSubscriptionModelFixture
    from ..models.video_subscription_model_organization import VideoSubscriptionModelOrganization


T = TypeVar("T", bound="VideoSubscriptionModel")


@_attrs_define
class VideoSubscriptionModel:
    """
    Attributes:
        subscription_id (Union[Unset, UUID]): The unique identifier of the video stream subscription Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, VideoSubscriptionModelOrganization]): The organization that this video subscription
            belongs to
        customer_id (Union[None, Unset, int]): Customer of the subscription Example: 1.
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, VideoSubscriptionModelFixture]): The match
        provider (Union[Unset, str]): The code for the provider of the file Example: Test Provider.
        locale (Union[Unset, str]): The locale of the video Example: fr-FR.
        source_number (Union[Unset, int]): Unique identifier for the video source. This is unique for the
            provider/fixtureId/locale combination.  Unless the provider is supplying multiple sources per fixture/locale
            then this is normally 1. Default: 1. Example: 1.
        feed_type (Union[Unset, VideoSubscriptionModelFeedType]): Type of video input
            >- `ADDITIONAL_ANGLE` Additional angle
            >- `LOW_LATENCY` Low Latency
            >- `PRIMARY` Primary
             Example: PRIMARY.
        output_resolution (Union[Unset, VideoSubscriptionModelOutputResolution]): The resolution that you want to
            receive the video in.  This is only valid if outputFormat is `RTMP`.  If outputFormat is not `RTMP` then the
            output resolution is the same as the input resolution.  If specified the output resolution cannot be higher than
            the input resolution. You must have specific permission to chose anything other than 720p or 1080p.
            >- `1080` 1920 x 1080
            >- `1080i50@10M` SRT 1080i50@10M
            >- `1080p25@10M` SRT 1080p25@10M
            >- `1080p50@10M` SRT 1080p50@10M
            >- `1280x720@2000k` 1280x720@2000k
            >- `1280x720@3000k` 1280x720@3000k
            >- `1280x720@3000k25fps` 1280x720@3000k25fps
            >- `1920x1080@4000k` 1920x1080@4000k
            >- `1920x1080@4000k25fps` 1920x1080@4000k25fps
            >- `1920x1080@4500k` 1920x1080@4500k
            >- `1920x1080@5000k30fps` 1920x1080@5000k30fps
            >- `2000` 2000
            >- `288` 512 x 288
            >- `640x320@850k` 640x320@850k
            >- `720` 1280 x 720
            >- `DESKTOP_384x216@280k` DESKTOP_384x216@280k
            >- `DESKTOP_512x288@500k` DESKTOP_512x288@500k
            >- `DESKTOP_768x432@1000k` DESKTOP_768x432@1000k
            >- `MOBILE_320x180@102k` MOBILE_320x180@102k
            >- `MOBILE_320x180@102k_BUFFERED` MOBILE_320x180@102k_BUFFERED
            >- `MOBILE_320x180@232k` MOBILE_320x180@232k
            >- `MOBILE_320x180@232k_BUFFERED` MOBILE_320x180@232k_BUFFERED
            >- `MOBILE_480x270@464k` MOBILE_480x270@464k
            >- `MOBILE_480x270@464k_BUFFERED` MOBILE_480x270@464k_BUFFERED
            >- `MOBILE_768x432@1000k` MOBILE_768x432@1000k
            >- `MOBILE_768x432@1000k_BUFFERED` MOBILE_768x432@1000k_BUFFERED
             Example: 720.
        output_format (Union[Unset, VideoSubscriptionModelOutputFormat]): The output format
            >- `HLS` HLS
            >- `RTMP` RTMP
            >- `RTMP_PULL` RTMP Pull
            >- `SRT` SRT
             Example: RTMP.
        stream_name (Union[Unset, str]): The name/stream key of the RTMP stream. This is an optional part of the RTMP
            url - not a text description.
        subscription_name (Union[Unset, str]): The name of the subscription
        output_url (Union[Unset, str]): The URL to send the output to. Only valid if outputFormat is 'RTMP' or 'SRT'
            Example: rtmp://rtmp-api.facebook.com:80/rtmp/?340ur0JHKJ0398hjkh387HKJD9.
        audio (Union[Unset, VideoSubscriptionModelAudio]): Audio
            >- `AMBIENCE` Only ambience / crowd noise
            >- `BOTH` Both combined
            >- `BOTH_SPLIT_LR` Both (Ambience left channel, Commentary right channel)
            >- `COMMENTARY` Only commentary
             Default: VideoSubscriptionModelAudio.BOTH. Example: COMMENTARY.
        content (Union[Unset, VideoSubscriptionModelContent]): Content of the stream
            >- `CLEAN` Output signal is the same as the input signal
            >- `PROGRAM` Score overlays and other enhancements have been added to the stream
             Example: CLEAN.
        mux_rate (Union[Unset, int]): The muxRate of the stream. Required for SRT outputFormat only. Example: 1200000.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    subscription_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "VideoSubscriptionModelOrganization"] = UNSET
    customer_id: Union[None, Unset, int] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "VideoSubscriptionModelFixture"] = UNSET
    provider: Union[Unset, str] = UNSET
    locale: Union[Unset, str] = UNSET
    source_number: Union[Unset, int] = 1
    feed_type: Union[Unset, VideoSubscriptionModelFeedType] = UNSET
    output_resolution: Union[Unset, VideoSubscriptionModelOutputResolution] = UNSET
    output_format: Union[Unset, VideoSubscriptionModelOutputFormat] = UNSET
    stream_name: Union[Unset, str] = UNSET
    subscription_name: Union[Unset, str] = UNSET
    output_url: Union[Unset, str] = UNSET
    audio: Union[Unset, VideoSubscriptionModelAudio] = VideoSubscriptionModelAudio.BOTH
    content: Union[Unset, VideoSubscriptionModelContent] = UNSET
    mux_rate: Union[Unset, int] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        subscription_id: Union[Unset, str] = UNSET
        if not isinstance(self.subscription_id, Unset):
            subscription_id = str(self.subscription_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        customer_id: Union[None, Unset, int]
        if isinstance(self.customer_id, Unset):
            customer_id = UNSET
        else:
            customer_id = self.customer_id

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        provider = self.provider

        locale = self.locale

        source_number = self.source_number

        feed_type: Union[Unset, str] = UNSET
        if not isinstance(self.feed_type, Unset):
            feed_type = self.feed_type.value

        output_resolution: Union[Unset, str] = UNSET
        if not isinstance(self.output_resolution, Unset):
            output_resolution = self.output_resolution.value

        output_format: Union[Unset, str] = UNSET
        if not isinstance(self.output_format, Unset):
            output_format = self.output_format.value

        stream_name = self.stream_name

        subscription_name = self.subscription_name

        output_url = self.output_url

        audio: Union[Unset, str] = UNSET
        if not isinstance(self.audio, Unset):
            audio = self.audio.value

        content: Union[Unset, str] = UNSET
        if not isinstance(self.content, Unset):
            content = self.content.value

        mux_rate = self.mux_rate

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if subscription_id is not UNSET:
            field_dict["subscriptionId"] = subscription_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if customer_id is not UNSET:
            field_dict["customerId"] = customer_id
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if provider is not UNSET:
            field_dict["provider"] = provider
        if locale is not UNSET:
            field_dict["locale"] = locale
        if source_number is not UNSET:
            field_dict["sourceNumber"] = source_number
        if feed_type is not UNSET:
            field_dict["feedType"] = feed_type
        if output_resolution is not UNSET:
            field_dict["outputResolution"] = output_resolution
        if output_format is not UNSET:
            field_dict["outputFormat"] = output_format
        if stream_name is not UNSET:
            field_dict["streamName"] = stream_name
        if subscription_name is not UNSET:
            field_dict["subscriptionName"] = subscription_name
        if output_url is not UNSET:
            field_dict["outputURL"] = output_url
        if audio is not UNSET:
            field_dict["audio"] = audio
        if content is not UNSET:
            field_dict["content"] = content
        if mux_rate is not UNSET:
            field_dict["muxRate"] = mux_rate
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.video_subscription_model_fixture import VideoSubscriptionModelFixture
        from ..models.video_subscription_model_organization import VideoSubscriptionModelOrganization

        d = dict(src_dict)
        _subscription_id = d.pop("subscriptionId", UNSET)
        subscription_id: Union[Unset, UUID]
        if isinstance(_subscription_id, Unset):
            subscription_id = UNSET
        else:
            subscription_id = UUID(_subscription_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, VideoSubscriptionModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = VideoSubscriptionModelOrganization.from_dict(_organization)

        def _parse_customer_id(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        customer_id = _parse_customer_id(d.pop("customerId", UNSET))

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, VideoSubscriptionModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = VideoSubscriptionModelFixture.from_dict(_fixture)

        provider = d.pop("provider", UNSET)

        locale = d.pop("locale", UNSET)

        source_number = d.pop("sourceNumber", UNSET)

        _feed_type = d.pop("feedType", UNSET)
        feed_type: Union[Unset, VideoSubscriptionModelFeedType]
        if isinstance(_feed_type, Unset):
            feed_type = UNSET
        else:
            feed_type = VideoSubscriptionModelFeedType(_feed_type)

        _output_resolution = d.pop("outputResolution", UNSET)
        output_resolution: Union[Unset, VideoSubscriptionModelOutputResolution]
        if isinstance(_output_resolution, Unset):
            output_resolution = UNSET
        else:
            output_resolution = VideoSubscriptionModelOutputResolution(_output_resolution)

        _output_format = d.pop("outputFormat", UNSET)
        output_format: Union[Unset, VideoSubscriptionModelOutputFormat]
        if isinstance(_output_format, Unset):
            output_format = UNSET
        else:
            output_format = VideoSubscriptionModelOutputFormat(_output_format)

        stream_name = d.pop("streamName", UNSET)

        subscription_name = d.pop("subscriptionName", UNSET)

        output_url = d.pop("outputURL", UNSET)

        _audio = d.pop("audio", UNSET)
        audio: Union[Unset, VideoSubscriptionModelAudio]
        if isinstance(_audio, Unset):
            audio = UNSET
        else:
            audio = VideoSubscriptionModelAudio(_audio)

        _content = d.pop("content", UNSET)
        content: Union[Unset, VideoSubscriptionModelContent]
        if isinstance(_content, Unset):
            content = UNSET
        else:
            content = VideoSubscriptionModelContent(_content)

        mux_rate = d.pop("muxRate", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        video_subscription_model = cls(
            subscription_id=subscription_id,
            organization_id=organization_id,
            organization=organization,
            customer_id=customer_id,
            fixture_id=fixture_id,
            fixture=fixture,
            provider=provider,
            locale=locale,
            source_number=source_number,
            feed_type=feed_type,
            output_resolution=output_resolution,
            output_format=output_format,
            stream_name=stream_name,
            subscription_name=subscription_name,
            output_url=output_url,
            audio=audio,
            content=content,
            mux_rate=mux_rate,
            updated=updated,
            added=added,
        )

        return video_subscription_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.change_log_model_change_type import ChangeLogModelChangeType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.change_log_model_organization import ChangeLogModelOrganization


T = TypeVar("T", bound="ChangeLogModel")


@_attrs_define
class ChangeLogModel:
    """
    Attributes:
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, ChangeLogModelOrganization]): The organization that this change_log belongs to
        change_type (Union[Unset, ChangeLogModelChangeType]): The type of change
            >- `delete` Record Deleted
            >- `fixture_change` Fixture schedule Change
            >- `fixture_reset` Fixture Reset
            >- `fixture_videostream_disable` Enable Video Stream
            >- `fixture_videostream_enable` Enable Video Stream
            >- `move` Record Moved
            >- `post` Record Created
            >- `put` Record Changed
            >- `update` Record Updated
             Example: delete.
        primary_type (Union[Unset, str]): The primary table changed Example: fixtures.
        primary_id (Union[Unset, UUID]): The unique identifier of the primaryType Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        child_type (Union[Unset, str]): The child table changed Example: fixture_roster.
        change_message (Union[Unset, Any]):
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "ChangeLogModelOrganization"] = UNSET
    change_type: Union[Unset, ChangeLogModelChangeType] = UNSET
    primary_type: Union[Unset, str] = UNSET
    primary_id: Union[Unset, UUID] = UNSET
    child_type: Union[Unset, str] = UNSET
    change_message: Union[Unset, Any] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        change_type: Union[Unset, str] = UNSET
        if not isinstance(self.change_type, Unset):
            change_type = self.change_type.value

        primary_type = self.primary_type

        primary_id: Union[Unset, str] = UNSET
        if not isinstance(self.primary_id, Unset):
            primary_id = str(self.primary_id)

        child_type = self.child_type

        change_message = self.change_message

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if change_type is not UNSET:
            field_dict["changeType"] = change_type
        if primary_type is not UNSET:
            field_dict["primaryType"] = primary_type
        if primary_id is not UNSET:
            field_dict["primaryId"] = primary_id
        if child_type is not UNSET:
            field_dict["childType"] = child_type
        if change_message is not UNSET:
            field_dict["changeMessage"] = change_message
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.change_log_model_organization import ChangeLogModelOrganization

        d = dict(src_dict)
        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, ChangeLogModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = ChangeLogModelOrganization.from_dict(_organization)

        _change_type = d.pop("changeType", UNSET)
        change_type: Union[Unset, ChangeLogModelChangeType]
        if isinstance(_change_type, Unset):
            change_type = UNSET
        else:
            change_type = ChangeLogModelChangeType(_change_type)

        primary_type = d.pop("primaryType", UNSET)

        _primary_id = d.pop("primaryId", UNSET)
        primary_id: Union[Unset, UUID]
        if isinstance(_primary_id, Unset):
            primary_id = UNSET
        else:
            primary_id = UUID(_primary_id)

        child_type = d.pop("childType", UNSET)

        change_message = d.pop("changeMessage", UNSET)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        change_log_model = cls(
            organization_id=organization_id,
            organization=organization,
            change_type=change_type,
            primary_type=primary_type,
            primary_id=primary_id,
            child_type=child_type,
            change_message=change_message,
            added=added,
        )

        return change_log_model
